@@ -1,9 +1,9 @@
 use crate::utils::{get_pkgs, ListOpt, Listable, Result};
 use cargo_metadata::Metadata;
-use clap::Clap;
+use clap::Parser;
 
 /// List crates in the project
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 #[clap(alias = "ls")]
 pub struct List {
     #[clap(flatten)]
