@@ -38,7 +38,7 @@ impl ChangeData {
             args.push("--first-parent");
         }
 
-        let (description, _) = git(&metadata.workspace_root, &args)?;
+        let (_, description, _) = git(&metadata.workspace_root, &args)?;
 
         let sha_regex = Regex::new("^([0-9a-f]{7,40})(-dirty)?$").expect(INTERNAL_ERR);
         let tag_regex =
@@ -52,7 +52,7 @@ impl ChangeData {
             ret.sha = caps.get(1).expect(INTERNAL_ERR).as_str().to_string();
             ret.dirty = caps.get(2).is_some();
 
-            let (count, _) = git(&metadata.workspace_root, &["rev-list", "--count", &ret.sha])?;
+            let (_, count, _) = git(&metadata.workspace_root, &["rev-list", "--count", &ret.sha])?;
 
             ret.count = count;
         } else if tag_regex.is_match(&description) {
@@ -77,17 +77,17 @@ impl ChangeOpt {
         since: &Option<String>,
         private: bool,
     ) -> Result<(Vec<Pkg>, Vec<Pkg>), Error> {
-        let pkgs = get_pkgs(&metadata, private)?;
+        let pkgs = get_pkgs(metadata, private)?;
 
         let pkgs = if let Some(since) = since {
             info!("looking for changes since", since);
 
-            let (changed_files, _) = git(
+            let (_, changed_files, _) = git(
                 &metadata.workspace_root,
                 &["diff", "--name-only", "--relative", since],
             )?;
 
-            let changed_files = changed_files.split("\n").map(Path::new).collect::<Vec<_>>();
+            let changed_files = changed_files.split('\n').map(Path::new).collect::<Vec<_>>();
             let force = self
                 .force
                 .clone()
